Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1915)

Unified Diff: dbus/bus.h

Issue 9373039: Allow dbus clients to silence logging when a service is unavailable. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Use pair, factor out error logging logic Created 8 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | dbus/bus.cc » ('j') | dbus/object_proxy.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: dbus/bus.h
diff --git a/dbus/bus.h b/dbus/bus.h
index 4af07ce1089fc2585a3c0eb6ff5dd040458e8600..d44b9a67206a535a9483a212b8c949f20f7a629e 100644
--- a/dbus/bus.h
+++ b/dbus/bus.h
@@ -196,6 +196,13 @@ class Bus : public base::RefCountedThreadSafe<Bus> {
virtual ObjectProxy* GetObjectProxy(const std::string& service_name,
const std::string& object_path);
+ // Same as above, but also takes a bitfield of ObjectProxy::Options.
+ // See object_proxy.h for available options.
+ virtual ObjectProxy* GetObjectProxyWithOptions(
+ const std::string& service_name,
+ const std::string& object_path,
+ int options);
+
// Gets the exported object for the given service name and the object
// path. The caller must not delete the returned object.
//
@@ -459,9 +466,11 @@ class Bus : public base::RefCountedThreadSafe<Bus> {
filter_functions_added_;
// ObjectProxyTable is used to hold the object proxies created by the
- // bus object. Key is a concatenated string of service name + object path,
- // like "org.chromium.TestService/org/chromium/TestObject".
- typedef std::map<std::string,
+ // bus object. Key is a pair; the first part is a concatenated string of
+ // service name + object path, like
+ // "org.chromium.TestService/org/chromium/TestObject".
+ // The second part is the ObjectProxy::Options for the proxy.
+ typedef std::map<std::pair<std::string, int>,
scoped_refptr<dbus::ObjectProxy> > ObjectProxyTable;
ObjectProxyTable object_proxy_table_;
« no previous file with comments | « no previous file | dbus/bus.cc » ('j') | dbus/object_proxy.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698